==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebNavDrawerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNavDrawerDescription } from "./WebNavDrawerDescription";
/**
 * @hidden
 */
var WebNavDrawerDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebNavDrawerDescriptionMetadata, _super);
    function WebNavDrawerDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebNavDrawerDescriptionMetadata.b = function (a) {
        if (WebNavDrawerDescriptionMetadata.a == null) {
            WebNavDrawerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebNavDrawerDescriptionMetadata.c(WebNavDrawerDescriptionMetadata.a);
        }
        if (a.k(WebNavDrawerDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebNavDrawerDescriptionMetadata.a);
    };
    WebNavDrawerDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:NavDrawer");
        a.item("__tagNameWC", "String:igc-nav-drawer");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Position", "ExportedType:string:NavDrawerPosition");
        a.item("Position@stringUnion", "WebComponents;React");
        a.item("Position@names", "Top;Bottom;Start;End;Relative");
        a.item("Open", "Boolean");
    };
    WebNavDrawerDescriptionMetadata.d = function (a) {
        WebNavDrawerDescriptionMetadata.b(a);
        a.ad("WebNavDrawer", function () { return new WebNavDrawerDescription(); });
        a.ac("WebNavDrawer", WebNavDrawerDescriptionMetadata.a);
    };
    WebNavDrawerDescriptionMetadata.$t = markType(WebNavDrawerDescriptionMetadata, 'WebNavDrawerDescriptionMetadata');
    WebNavDrawerDescriptionMetadata.a = null;
    return WebNavDrawerDescriptionMetadata;
}(Base));
export { WebNavDrawerDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/WebNavDrawerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNavDrawerDescription } from "./WebNavDrawerDescription";
/**
 * @hidden
 */
var WebNavDrawerDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebNavDrawerDescriptionMetadata, _super);
    function WebNavDrawerDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebNavDrawerDescriptionMetadata.b = function (a) {
        if (WebNavDrawerDescriptionMetadata.a == null) {
            WebNavDrawerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebNavDrawerDescriptionMetadata.c(WebNavDrawerDescriptionMetadata.a);
        }
        if (a.k(WebNavDrawerDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebNavDrawerDescriptionMetadata.a);
    };
    WebNavDrawerDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:NavDrawer");
        a.item("__tagNameWC", "String:igc-nav-drawer");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Position", "ExportedType:string:NavDrawerPosition");
        a.item("Position@stringUnion", "WebComponents;React");
        a.item("Position@names", "Start;End;Bottom;Top;Relative");
        a.item("Open", "Boolean");
    };
    WebNavDrawerDescriptionMetadata.d = function (a) {
        WebNavDrawerDescriptionMetadata.b(a);
        a.ae("WebNavDrawer", function () { return new WebNavDrawerDescription(); });
        a.ad("WebNavDrawer", WebNavDrawerDescriptionMetadata.a);
    };
    WebNavDrawerDescriptionMetadata.$t = markType(WebNavDrawerDescriptionMetadata, 'WebNavDrawerDescriptionMetadata');
    WebNavDrawerDescriptionMetadata.a = null;
    return WebNavDrawerDescriptionMetadata;
}(Base));
export { WebNavDrawerDescriptionMetadata };
